@@ -2,7 +2,7 @@ from typing import List, Dict, Union, Optional
 import sqlite3
 import re
 from collections import OrderedDict
-from utils import Range
+from mybible.utils import Range
 
 class Book:
     def __init__(self, book_number: int, short_name: str, long_name: str, book_color: str,
